import uwsgi
if uwsgi.loop == 'gevent':
    import gevent

from threading import Thread
import time
from uwsgidecorators import postfork

def foobar():
    while True:
        time.sleep(3)
        print "threee second elapsed in worker %d" % uwsgi.worker_id()

@postfork
def spawn_thread():
    t = Thread(target=foobar)
    t.daemon = True
    t.start()

@postfork
def spawn_thread2():
    t = Thread(target=foobar)
    t.daemon = True
    t.start()

def gl_func():
    while True:
        gevent.sleep(2)
        print "i am a greenltet running in worker %d" % uwsgi.worker_id()

@postfork
def spawn_greenlet():
    gevent.spawn(gl_func)

print uwsgi.version
print uwsgi.workers()
try:
    uwsgi.cache_set('foo', "Hello World from cache")
except:
    pass
def application(env, start_response):
    print env['wsgi.input'].read()
    if uwsgi.loop == 'gevent':
        gevent.sleep()
    start_response('200 OK', [('Content-Type', 'text/html')])
    yield "foobar<br/>"
    if uwsgi.loop == 'gevent':
        gevent.sleep(3)
    yield str(env['wsgi.input'].fileno())
    yield "<h1>Hello World</h1>"
    try:
        yield uwsgi.cache_get('foo')
    except:
        pass



#!./uwsgi
import uwsgi

from bottle import route, default_app, request, response, redirect

@route('/')
def chat():
    return """<iframe src="/recv"></iframe>
    <iframe src="/sender"></iframe>"""

@route('/sender')
def sender():
    return """<form method="GET" action="/send">
<textarea name="message"></textarea><br/>
<input type="submit" value="send" />
</form>"""



@route('/recv')
def recv():
    response.header['Transfer-Encoding'] = 'chunked'

    # this will flush headers
    yield ""

    running = True
    while running:
        # this will put the core in pause (for max 10 seconds) and remove it from the sched queue, so the /send can write to its socket
        if not uwsgi.green_pause(10):
            running = False
        # this will maintain the connection opened if no data arrives
        yield "<span/>"


@route('/send')
def send():
    # this will write to all the core in PAUSED state
    uwsgi.green_write_all(request.GET['message'] + "<br/>")
    # this will unpause all the paused cores, so they will be re-inserted in the sched queue
    uwsgi.green_unpause_all()
    redirect('/sender')


application = default_app()



import os

NAME='php'

ld_run_path = None
PHPPATH = 'php-config'

try:
    phpdir = os.environ['UWSGICONFIG_PHPDIR']
    ld_run_path = "%s/lib" % phpdir
    PHPPATH = "%s/bin/php-config" % phpdir
except:
    pass

try:
    PHPPATH = os.environ['UWSGICONFIG_PHPPATH']
except:
    pass

CFLAGS = [os.popen(PHPPATH + ' --includes').read().rstrip(), '-Wno-error=sign-compare']

LDFLAGS = os.popen(PHPPATH + ' --ldflags').read().rstrip().split()
if ld_run_path:
    LDFLAGS.append('-L%s' % ld_run_path)
    os.environ['LD_RUN_PATH'] = ld_run_path

LIBS = [os.popen(PHPPATH + ' --libs').read().rstrip(), '-lphp5']

GCC_LIST = ['php_plugin']



import sys
import os
import pyuwsgi

orig_args = sys.argv
orig_executable = sys.executable
orig_args.insert(0, orig_executable)

uwsgi_args = []

uwsgi_args.append('--socket')
uwsgi_args.append(':3031')
#uwsgi_args.append('--master')
uwsgi_args.append('--module')
#uwsgi_args.append('welcome')
uwsgi_args.append('hello')

#pyuwsgi.run('welcome.ini')
pyuwsgi.run(uwsgi_args)

# if you are here uWSGI has been reloaded
os.execv(orig_executable, orig_args)



import uwsgi
import time
import rrdtool

# rrdtool create test.rrd --start 1270879004 -s 10 DS:requests:COUNTER:300:U:U RRA:AVERAGE:0.5:3:105120

s_freq = 10

# this task will be executed every s_freq seconds
def rrdtool_updater(sig, sec):
	rrdtool.update('test.rrd', str(int(time.time()))+':'+str(uwsgi.total_requests()))

	
uwsgi.register_timer(0, s_freq, uwsgi.KIND_WORKER, rrdtool_updater)
	


def hello_world(env, start_response):
	start_response('200 Ok', [('Content-type', 'text/plain')])
	return 'Hello world !'


def graph(env, start_response):
	start_response('200 Ok', [('Content-type', 'image/png')])
	now = int(time.time())
	graph_range = (3600*24)
	rrdtool.graph('uwsgi_graph.png', '--start', str(now - graph_range), '--end', str(now), 'DEF:urequests=test.rrd:requests:AVERAGE', 'LINE2:urequests#00FF00')
	# send file to client
	uwsgi.sendfile('uwsgi_graph.png')

uwsgi.applications = {'/': hello_world, '/graph':graph}
